@@ -21,7 +21,6 @@
 
 #include <gtk/gtk.h>
 #include <gdk/gdkx.h>
-#include <gdk-pixbuf-xlib/gdk-pixbuf-xlib.h>
 
 #include <gpe/init.h>
 #include <gpe/pixmaps.h>
@@ -38,6 +37,7 @@
 GtkWidget *slider_window;
 GtkWidget *window, *slider;
 GtkWidget *icon;
+GdkBitmap *bitmap;
 
 int mixerfd;
 
@@ -107,33 +107,11 @@ configure_event (GtkWidget *window, GdkEventConfigure *event)
 {
   GdkPixbuf *buf;
   int xoff, yoff;
-  int x, y;
-  Window w, parent = None, root;
-  Window *children = NULL;
-  unsigned int nchildren;
-  Display *dpy;
-  XWindowAttributes attr;
-
-  w = GDK_WINDOW_XWINDOW (event->window);
-  dpy = GDK_WINDOW_XDISPLAY (event->window);
-  XGetWindowAttributes (dpy, w, &attr);
-  XQueryTree (dpy, w, &root, &parent, &children, &nchildren);
-  if (children)
-    XFree (children);
-
-  buf = gdk_pixbuf_xlib_get_from_drawable (NULL, parent, None, NULL,
-					   attr.x, attr.y, 0, 0, 
-					   event->width, event->height);
 
   xoff = (event->width - 30) / 2;
   yoff = (event->height - 32) / 2;
 
-  gdk_pixbuf_composite (gpe_find_icon ("minimix"), buf, xoff, yoff, 30, 32,
-			xoff, yoff, 1.0, 1.0, GDK_INTERP_BILINEAR, 255);
-  
-  gtk_image_set_from_pixbuf (GTK_IMAGE (icon), buf);
-
-  g_object_unref (buf);
+  gtk_widget_shape_combine_mask (window, bitmap, 0, 0);
  
   return FALSE;
 }
@@ -158,8 +136,6 @@ main (int argc, char **argv)
   gtk_widget_set_usize (window, 30, 32);
   gtk_widget_realize (window);
 
-  gdk_pixbuf_xlib_init_with_depth (GDK_WINDOW_XDISPLAY (window->window), 0, 24);
-
   if (gpe_load_icons (my_icons) == FALSE) 
     {
       gpe_error_box (_("Failed to load icons"));
@@ -181,6 +157,9 @@ main (int argc, char **argv)
   tooltips = gtk_tooltips_new ();
   gtk_tooltips_set_tip (GTK_TOOLTIPS (tooltips), window, _("This is the volume control.  Tap here and drag the slider to change the speaker volume."), NULL);
 
+  gdk_pixbuf_render_pixmap_and_mask (gpe_find_icon ("minimix"), NULL, &bitmap, 255);
+  gtk_widget_shape_combine_mask (window, bitmap, 0, 0);
+
   icon = gtk_image_new_from_pixbuf (gpe_find_icon ("minimix"));
   gtk_container_add (GTK_CONTAINER (window), icon);
 
